API Reference
=============

.. automodule:: cfel_fmt
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   crystfel_stream <cfel_fmt.crystfel_stream>
   geometry <cfel_fmt.geometry>
